Changelog — django-guardian v0.2.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v0.2.2 documentation »

# Changelog

## Release 0.2.1 (Oct 3, 2010)

- Fixed migration (it wasn’t actually updating object_pk field)

## Release 0.2.0 (Oct 3, 2010)

### Fixes

- #4: guardian now supports models with not-integer primary keys and they don’t need to be called “id”.

  Important

  For 0.1.X users: it is required to migrate guardian in your projects. Add `south` to `INSTALLED_APPS` and run:

      python manage.py syncdb
      python manage.py migrate guardian 0001 --fake
      python manage.py migrate guardian

### Improvements

- Added South migrations support

## Release 0.1.1 (Sep 27, 2010)

### Improvements

- Added view decorators: `permission_required` and `permission_required_403`

## Release 0.1.0 (Jun 6, 2010)

- Initial public release

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v0.2.2 documentation »